"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cloud_functions_1 = require("../methods/cloud-functions");
const fixtures_1 = require("./fixtures");
describe('cloud functions', () => {
    it('should forward requests', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const handler = jest.fn();
        const send = jest.fn();
        const payload = fixtures_1.createPubSubRequest('forward me');
        const fun = cloud_functions_1.createPubSubCloudFunctions(handler);
        yield fun({ body: payload }, { status: () => ({ send }) });
        expect(handler).toHaveBeenCalledWith({
            message: payload.message,
            data: 'forward me',
            context: JSON.parse(JSON.stringify(payload)),
        });
    }));
    it('should run onError when thrown', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const payload = fixtures_1.createPubSubRequest('forward me');
        const handle = () => {
            throw new Error('error');
        };
        const onError = jest.fn();
        const send = jest.fn();
        const fun = yield cloud_functions_1.createPubSubCloudFunctions(handle, { onError });
        yield fun({ body: payload }, { status: () => ({ send }) });
        expect(onError).toHaveBeenCalledWith(new Error('error'));
    }));
    it('should throw when onError is undefined', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const payload = fixtures_1.createPubSubRequest('forward me');
        const handle = () => {
            throw new Error('error');
        };
        const send = jest.fn();
        const fun = yield cloud_functions_1.createPubSubCloudFunctions(handle);
        yield fun({ body: payload }, { status: () => ({ send }) }).catch(e => expect(e.message).toBe('error'));
    }));
});
