"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fastify_1 = require("fastify");
const fastify_plugin_1 = require("../methods/fastify-plugin");
const fixtures_1 = require("./fixtures");
describe('fastify-plugin', () => {
    let app;
    beforeEach(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        app = fastify_1.default();
    }));
    afterAll(() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        yield app.close();
    }));
    it('should forward requests', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const handler = jest.fn();
        const payload = fixtures_1.createPubSubRequest('forward me');
        app.register(fastify_plugin_1.pubSubFastifyPlugin, { handler });
        const res = yield app.inject({
            method: 'POST',
            url: '/',
            payload,
        });
        expect(res.statusCode).toBe(204);
        expect(handler).toHaveBeenCalledWith({
            message: payload.message,
            data: 'forward me',
            context: JSON.parse(JSON.stringify(payload)),
        });
    }));
    it('should forward statusCode', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const handler = jest.fn(() => ({ statusCode: 404 }));
        const payload = fixtures_1.createPubSubRequest('forward me');
        app.register(fastify_plugin_1.pubSubFastifyPlugin, { handler });
        const res = yield app.inject({
            method: 'POST',
            url: '/',
            payload,
        });
        expect(res.statusCode).toBe(404);
        expect(handler).toHaveBeenCalledWith({
            message: payload.message,
            data: 'forward me',
            context: JSON.parse(JSON.stringify(payload)),
        });
    }));
    it('should return onError on throw', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const handler = () => {
            throw new Error('error');
        };
        const onError = jest.fn();
        const payload = fixtures_1.createPubSubRequest('forward me');
        app.register(fastify_plugin_1.pubSubFastifyPlugin, { handler, onError });
        yield app.inject({
            method: 'POST',
            url: '/',
            payload,
        });
        expect(onError).toHaveBeenCalledWith(new Error('error'));
    }));
    it('should not return onError on throw', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const handler = () => {
            throw new Error('error');
        };
        const payload = fixtures_1.createPubSubRequest('forward me');
        app.register(fastify_plugin_1.pubSubFastifyPlugin, { handler });
        const res = yield app.inject({
            method: 'POST',
            url: '/',
            payload,
        });
        expect(res.payload).toMatchInlineSnapshot(`"{\\"statusCode\\":500,\\"error\\":\\"Internal Server Error\\",\\"message\\":\\"error\\"}"`);
    }));
});
