"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pubSubFastifyPlugin = void 0;
const tslib_1 = require("tslib");
const fastify_plugin_1 = require("fastify-plugin");
const common_1 = require("../common");
const types_1 = require("../types");
const pubSubFastifyPluginAsync = (fastify, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const { path = '/', handler, parseJson, onError } = options;
    fastify.post(path, {
        schema: {
            body: types_1.PubSubRequest,
            response: { 204: {} },
        },
    }, (req, reply) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        try {
            const res = yield common_1.handlePubSubMessage({
                message: req.body.message,
                handler,
                parseJson,
                context: req.body,
            });
            reply.code((res && res.statusCode) || 204);
        }
        catch (error) {
            if (onError) {
                yield onError(error);
                reply.code(204);
            }
            else
                throw error;
        }
        reply.send();
    }));
});
exports.pubSubFastifyPlugin = fastify_plugin_1.default(pubSubFastifyPluginAsync, '3.x');
